# Invpy package v1.1.0

- Package that includes several methods to compute statistical translation non-invariance of primarly, but not limitted to, scalar
cosmological fields.

## Major Bug fixes

- Fixed second and first kind estimator bias in nopbc_estimators.py method;

## Updates


